@@ -95,10 +95,14 @@
 #' graphics::image(t(x$img), col=grey(0:64/64), axes=FALSE, xlab="", ylab="",
 #'                 main="Spine1.dcm")
 #'
-#' @export readDICOMFile
+#' @export
 readDICOMFile <- function(fname, boffset=NULL, endian="little", flipud=TRUE,
                           skipSequence=FALSE, pixelData=TRUE,
                           warn=-1, debug=FALSE) {
+  
+  if (!file.exists(fname)) {
+    stop("DICOM file does not exist")
+  }
   ## Warnings?
   oldwarn <- getOption("warn")
   options(warn = warn)
@@ -161,7 +165,7 @@ readDICOMFile <- function(fname, boffset=NULL, endian="little", flipud=TRUE,
   iconv(rawToChar(str.raw[str.raw != as.raw(0)]), to=to)
 }
 #' @rdname readDICOMFile
-#' @export parseDICOMHeader
+#' @export
 parseDICOMHeader <- function(rawString, sq.txt="", endian="little",
                              verbose=FALSE) {
   ##
@@ -216,7 +220,7 @@ parseDICOMHeader <- function(rawString, sq.txt="", endian="little",
       dic <- oro.dicom::dicom.dic[dictionaryIndex, ]
     }
     if (verbose) {
-      cat("#", group, element, dic$name, dic$code, sep="\t")
+      cat("#", strseek, group, element, dic$name, dic$code, sep="\t")
     }
     b56 <- .rawToCharWithEmbeddedNuls(rawString[strseek + 5:6])
     b78 <- readBin(rawString[strseek + 7:8], "integer", size=2, endian=endian)
@@ -346,7 +350,7 @@ parseDICOMHeader <- function(rawString, sq.txt="", endian="little",
 #' \dQuote{sequences} may be included/excluded according to the logical
 #' variable \code{skipSequence} (default = \code{TRUE}).
 #'
-#' A resursive implementation of the code breaks the DICOM file into segments
+#' A recursive implementation of the code breaks the DICOM file into segments
 #' and calls itself to parse each segment.
 #'
 #' @aliases parsePixelData parseSpectroscopyData
@@ -366,49 +370,64 @@ parseDICOMHeader <- function(rawString, sq.txt="", endian="little",
 #' \url{http://en.wikipedia.org/wiki/Digital_Imaging_and_Communications_in_Medicine}
 #' @source See references.
 #' @keywords file
-#' @export parsePixelData
+#' @export
 parsePixelData <- function(rawString, hdr, endian="little", flipupdown=TRUE) {
   rows <- as.numeric(with(hdr, value[name == "Rows" & sequence == ""]))
   columns <- as.numeric(with(hdr, value[name == "Columns" & sequence == ""]))
   bytes <- as.numeric(with(hdr, value[name == "BitsAllocated" & sequence == ""])) / 8
   length <- as.numeric(with(hdr, length[name == "PixelData" & sequence == ""]))
   if (length <= 0) {
-    guess <- 1
-    stop(paste("Number of bytes in PixelData not specified; guess =", guess))
+    transferSyntaxUID <- with(hdr, length[name == "TransferSyntaxuID" & sequence == ""])
+    if (grepl("1.2.840.10008.1.2.4", transferSyntaxUID)) {
+      stop("JPEG/MPEG compression is not currently supported.")
+    }
+    if (grepl("1.2.840.10008.1.2.5", transferSyntaxUID)) {
+      stop("RLE compression is not currently supported.")
+    }
+    if (grepl("1.2.840.10008.1.2.1.99", transferSyntaxUID)) {
+      stop("The deflate transfer syntax is not currently supported.")
+    }
+    length <- rows * columns # length(rawString)
+    warning(paste("Number of bytes in PixelData not specified; guess =", length))
+    warning(paste("Length of raw vector =", length(rawString)))
   }
-  pixelRepresentation <- as.numeric(with(hdr, value[name == "PixelRepresentation" & sequence == ""]))
+  pixelRepresentation <-
+    as.numeric(with(hdr, value[name == "PixelRepresentation" & sequence == ""]))
   signed <- ifelse(pixelRepresentation == 1, TRUE, FALSE)
   imageData <- readBin(rawString[1:length], "integer", n=length, size=bytes,
                        signed=signed, endian=endian)
   if (length == rows * columns * bytes) { # 2D PixelData
     imageData <-  t(matrix(imageData[1:(columns * rows)], columns, rows))
     if (flipupdown) {
-      imageData <- imageData[rows:1, ]
+      imageData <- imageData[rows:1,]
     }
   } else { # 3D PixelData
     k <- length / rows / columns / bytes
     if (k == trunc(k)) {
       warning("3D DICOM file detected!")
-      samplesPerPixel <- with(hdr, value[grepl("SamplesPerPixel", name, ignore.case=TRUE) & sequence == ""])
+      samplesPerPixel <-
+        with(hdr, value[grepl("SamplesPerPixel", name, ignore.case=TRUE) & sequence == ""])
       if (samplesPerPixel == "1") { # && planarConfiguration == 0) {
         imageData <- array(imageData[1:(columns * rows * k)], c(columns, rows, k))
         imageData <- aperm(imageData, c(2,1,3))
         if (flipupdown) {
-          imageData <- imageData[rows:1, , ]
+          imageData <- imageData[rows:1,,]
         }
       } else {
-        planarConfiguration <- with(hdr, value[grepl("PlanarConfiguration", name, ignore.case=TRUE) & sequence == ""])
-        if (planarConfiguration == "0")
-          stop("Color channels are interlaced")
+        planarConfiguration <-
+          with(hdr, value[grepl("PlanarConfiguration", name, ignore.case=TRUE) & sequence == ""])
+        if (planarConfiguration == "0") {
+          stop("Color channels are interlaced.")
+        }
       }
     } else {
-      stop("Number of bytes in PixelData does not match dimensions of image")
+      stop("Number of bytes in PixelData does not match dimensions of image.")
     }
   }
   return(imageData)
 }
 #' @rdname parsePixelData
-#' @export parseSpectroscopyData
+#' @export
 parseSpectroscopyData <- function(rawString, hdr, endian="little") {
   numberOfFrames <- as.numeric(with(hdr, value[name == "NumberOfFrames" & sequence == ""]))
   rows <- as.numeric(with(hdr, value[name == "Rows" & sequence == ""]))
